package fitconnect.api.validation;

import fitconnect.api.domain.metadata.Metadata;
import fitconnect.api.domain.metadata.attachment.Attachment;
import fitconnect.api.domain.metadata.data.Data;

/**
 * A validator that ensure the integrity of the transferred metadata of a submission
 *
 * For further information see: <a href="https://docs.fitko.de/fit-connect/docs/sending/metadata#integrity">Metadata Integrity</a>
 */
public interface MetadataValidator {

    /**
     * Validated the metdata against a given schema
     *
     * @param metadata the current metadata object that is validated
     * @param jsonSchema the schema that is used to validate against
     *
     * @return a validation result with an optional error list
     */
    ValidationResult validateMetadataSchema(final Metadata metadata, String jsonSchema);

    /**
     * Checks if the message digest hashes of the metadatas {@link Data} and {@link Attachment}
     * are correct after transmission
     *
     * @param metadata the current metadata object that is validated
     *
     * @return a validation result with an optional error list
     */
    ValidationResult validateMetadataHashValues(final Metadata metadata);
}
